diff libtomcrypt/src/prngs/rc4.c @ 1435:f849a5ca2efc

update to libtomcrypt 1.17 (with Dropbear changes)
author Matt Johnston <matt@ucc.asn.au>
date Sat, 24 Jun 2017 17:50:50 +0800
parents 0cbe8f6dbf9e
children 6dba84798cd5
line wrap: on
line diff
--- a/libtomcrypt/src/prngs/rc4.c	Sat Jun 24 11:53:32 2017 +0800
+++ b/libtomcrypt/src/prngs/rc4.c	Sat Jun 24 17:50:50 2017 +0800
@@ -6,16 +6,16 @@
  * The library is free for all purposes without any express
  * guarantee it works.
  *
- * Tom St Denis, [email protected], http://libtomcrypt.com
+ * Tom St Denis, [email protected], http://libtom.org
  */
 #include "tomcrypt.h"
 
 /**
   @file rc4.c
-  RC4 PRNG, Tom St Denis
+  LTC_RC4 PRNG, Tom St Denis
 */  
 
-#ifdef RC4
+#ifdef LTC_RC4
 
 const struct ltc_prng_descriptor rc4_desc = 
 {
@@ -93,7 +93,7 @@
     XMEMCPY(key, s, 256);
     keylen = prng->rc4.x;
 
     /* make RC4 perm and shuffle */
     for (x = 0; x < 256; x++) {
         s[x] = x;
     }
@@ -250,7 +250,7 @@
        if (XMEMCMP(dst, tests[x].ct, 8)) {
 #if 0
           int y;
-          printf("\n\nRC4 failed, I got:\n"); 
+          printf("\n\nLTC_RC4 failed, I got:\n"); 
           for (y = 0; y < 8; y++) printf("%02x ", dst[y]);
           printf("\n");
 #endif
@@ -264,6 +264,6 @@
 #endif
 
 
-/* $Source: /cvs/libtom/libtomcrypt/src/prngs/rc4.c,v $ */
-/* $Revision: 1.9 $ */
-/* $Date: 2006/11/16 00:32:18 $ */
+/* $Source$ */
+/* $Revision$ */
+/* $Date$ */
@@ -93,7 +93,7 @@
     keylen = prng->rc4.x;
 
-    /* make RC4 perm and shuffle */
+    /* make LTC_RC4 perm and shuffle */
     for (x = 0; x < 256; x++) {
         s[x] = x;